@@ -22,11 +22,13 @@ my $_tcp_service   = $config->{'local_port'};
 my $_password      = $config->{'password'};
 my $_remotehost    = $config->{'server'};
 my $_remoteservice = $config->{'server_port'};
+my $_method = $config->{'method'};
 
 my $foo = Net::Shadowsocks::Server->new(
                                 local_address => $_tcp_host,
                                 local_port    => $_tcp_service,
                                 password      => $_password,
                                 server        => $_remotehost,
-                                server_port   => $_remoteservice
+                                server_port   => $_remoteservice,
+                                          method => $_method
                                );
