@@ -8,7 +8,7 @@ use Crypt::Random qw( makerandom_octet );
 
 
 
-our $VERSION = '0.6.2';
+our $VERSION = '0.6.3';
 
 
 
@@ -24,6 +24,7 @@ our $VERSION = '0.6.2';
     use AnyEvent::Handle;
     use AnyEvent::Socket;
     use Carp;
+    use Crypt::AuthEnc::GCM;
     use Crypt::Random qw( makerandom_octet );
     use Digest::MD5;
     use IO::Socket::Socks qw(:constants $SOCKS_ERROR ESOCKSPROTO);
@@ -317,6 +318,7 @@ our $VERSION = '0.6.2';
     use AnyEvent::Handle;
     use AnyEvent::Socket;
     use Carp;
+    use Crypt::AuthEnc::GCM;
     use Crypt::Random qw( makerandom_octet );
     use Digest::MD5;
     use Mcrypt;
@@ -352,8 +354,6 @@ our $VERSION = '0.6.2';
                 my $clientiv;
                 my $mode = 0;
 
-                #say $self->{method};
-                # say $self->{password};
                 my ($encryptor, $decryptor, $key, $iv) =
                   Net::Shadowsocks::_initialize_cipher($self->{method},
                                                        $self->{password});
@@ -629,8 +629,6 @@ sub _initialize_cipher($$)
     my $method   = shift;
     my $password = shift;
 
-    #say $method;
-    #say $password;
     my $encryptor;
     my $decryptor;
     my $key;
@@ -651,6 +649,14 @@ sub _initialize_cipher($$)
         $key = Net::Shadowsocks::_EVP_BytesToKey(8, 8, '', $password, 1);
         $iv = makerandom_octet(Length => 8);
     }
+    elsif($method eq 'aes-128-cfb')
+    {
+        $encryptor =
+          Mcrypt::mcrypt_load(Mcrypt::RIJNDAEL_128, '', Mcrypt::CFB, '');
+        $decryptor = Mcrypt::mcrypt_load(Mcrypt::RIJNDAEL_128, '', Mcrypt::CFB, '');
+        $key = Net::Shadowsocks::_EVP_BytesToKey(16, 16, '', $password, 1);
+        $iv = makerandom_octet(Length => 16);
+        }
     return $encryptor, $decryptor, $key, $iv;
 }
 
@@ -669,7 +675,7 @@ Net::Shadowsocks - An asynchronous, non-blocking shadowsocks client and server m
 
 =head1 VERSION
 
-version 0.6.2
+version 0.6.3
 
 =head1 SYNOPSIS
 
@@ -683,8 +689,14 @@ Shadowsocks protocol server module.
 
 Net::Shadowsocks is a Perl implementation of the shadowsocks (Chinese: 影梭) 
 protocol client and server , Shadowsocks is a secure transport protocol based on 
-SOCKS Protocol Version 5 (RFC 1928 ). Currently the only encryption method 
-supported is RC4-MD5 which is introduced into shadowsocks Python version 2.2. 
+SOCKS Protocol Version 5 (RFC 1928 ). . 
+
+Currently the encryption methods supported are, in the order of increasing cryptograhic 
+strength , RC4-MD5 ,DES-CFB and AES-CFB.  
+
+The RC4-MD5 method is compatible with Shadowsocks but DES-CFB and AES-CFB methods 
+are not.  If you choose to use DES-CFB or AES-CFB method, you need to run your own client 
+and server. 
 
 Project website https://osdn.net/projects/ssperl/
 
@@ -692,7 +704,7 @@ Net::Shadowsocks
 
 =head1 VERSION
 
-Version 0.6.2
+Version 0.6.3
 
 =head1 SUBROUTINES/METHODS
 
